@@ -1,6 +1,6 @@
 /***************************************************************************
  *   KMetronome - ALSA Sequencer based MIDI metronome                      *
- *   Copyright (C) 2005-2022 Pedro Lopez-Cabanillas <plcl@users.sf.net>    *
+ *   Copyright (C) 2005-2023 Pedro Lopez-Cabanillas <plcl@users.sf.net>    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -755,9 +755,18 @@ void KMetronome::setSelectedPattern(const QString& pattern)
 QString KMetronome::configuredLanguage()
 {
     if (m_language.isEmpty()) {
+        QLocale loc;
+#if QT_VERSION < QT_VERSION_CHECK(6, 3, 0)
+        QString defLang = loc.name().split('_').at(0).toLower();
+#else
+        QString defLang = QLocale::languageToCode(loc.language());
+#endif
+        if (defLang.isEmpty() || defLang == "en") {
+            defLang = "C";
+        }
         QSettings settings;
         settings.beginGroup("Settings");
-        m_language = settings.value("language").toString();
+        m_language = settings.value("language", defLang).toString();
         settings.endGroup();
     }
     //qDebug() << Q_FUNC_INFO << m_language;
@@ -810,7 +819,7 @@ void KMetronome::createLanguageMenu()
     }
     locales.sort();
     m_ui.menuLanguage->clear();
-    for (const QString& loc : qAsConst(locales)) {
+    for (const QString &loc : std::as_const(locales)) {
         QLocale qlocale(loc);
         QString localeName = loc == "C" ? QLocale::languageToString(QLocale::English) : qlocale.nativeLanguageName();
         QAction *action = new QAction(localeName.section(" ", 0, 0), this);
